@@ -22,7 +22,8 @@ class TaskResultAdmin(admin.ModelAdmin):
                     'status', 'worker')
     list_filter = ('status', 'date_done', 'periodic_task_name', 'task_name',
                    'worker')
-    readonly_fields = ('date_created', 'date_done', 'result', 'meta')
+    readonly_fields = ('date_created', 'date_started', 'date_done',
+                       'result', 'meta')
     search_fields = ('task_name', 'task_id', 'status', 'task_args',
                      'task_kwargs')
     fieldsets = (
@@ -49,6 +50,7 @@ class TaskResultAdmin(admin.ModelAdmin):
             'fields': (
                 'result',
                 'date_created',
+                'date_started',
                 'date_done',
                 'traceback',
                 'meta',
