@@ -1,13 +1,14 @@
 import binascii
 import json
 
-from celery import maybe_signature
+from celery import maybe_signature, states
 from celery.backends.base import BaseDictBackend, get_current_task
 from celery.exceptions import ChordError
 from celery.result import GroupResult, allow_join_result, result_from_tuple
 from celery.utils.log import get_logger
 from celery.utils.serialization import b64decode, b64encode
-from django.db import connection, transaction
+from django.db import connection, router, transaction
+from django.db.models.functions import Now
 from django.db.utils import InterfaceError
 from kombu.exceptions import DecodeError
 
@@ -86,8 +87,8 @@ class DatabaseBackend(BaseDictBackend):
             if task_kwargs is not None:
                 _, _, task_kwargs = self.encode_content(task_kwargs)
 
-            properties = getattr(request, 'properties', {}) or {}
-            periodic_task_name = properties.get('periodic_task_name', None)
+            periodic_task_name = getattr(request, 'periodic_task_name', None)
+
             extended_props.update({
                 'periodic_task_name': periodic_task_name,
                 'task_args': task_args,
@@ -144,6 +145,9 @@ class DatabaseBackend(BaseDictBackend):
             self._get_extended_properties(request, traceback)
         )
 
+        if status == states.STARTED:
+            task_props['date_started'] = Now()
+
         self.TaskModel._default_manager.store_result(**task_props)
         return result
 
@@ -194,6 +198,8 @@ class DatabaseBackend(BaseDictBackend):
 
     def cleanup(self):
         """Delete expired metadata."""
+        if not self.expires:
+            return
         self.TaskModel._default_manager.delete_expired(self.expires)
         self.GroupModel._default_manager.delete_expired(self.expires)
 
@@ -246,7 +252,7 @@ class DatabaseBackend(BaseDictBackend):
         if not gid or not tid:
             return
         call_callback = False
-        with transaction.atomic():
+        with transaction.atomic(using=router.db_for_write(ChordCounter)):
             # We need to know if `count` hits 0.
             # wrap the update in a transaction
             # with a `select_for_update` lock to prevent race conditions.
