@@ -1,3 +1,4 @@
+import datetime
 import json
 import pickle
 import re
@@ -11,6 +12,7 @@ from celery.result import AsyncResult, GroupResult
 from celery.utils.serialization import b64decode
 from celery.worker.request import Request
 from celery.worker.strategy import hybrid_to_proto2
+from django.test import TransactionTestCase
 
 from django_celery_results.backends.database import DatabaseBackend
 from django_celery_results.models import ChordCounter, TaskResult
@@ -548,6 +550,39 @@ class test_DatabaseBackend:
         tr = TaskResult.objects.get(task_id=tid2)
         assert json.loads(tr.meta) == {'key': 'value', 'children': []}
 
+    def test_backend__task_result_date(self):
+        tid2 = uuid()
+
+        self.b.store_result(tid2, None, states.PENDING)
+
+        tr = TaskResult.objects.get(task_id=tid2)
+        assert tr.status == states.PENDING
+        assert isinstance(tr.date_created, datetime.datetime)
+        assert tr.date_started is None
+        assert isinstance(tr.date_done, datetime.datetime)
+
+        date_created = tr.date_created
+        date_done = tr.date_done
+
+        self.b.mark_as_started(tid2)
+
+        tr = TaskResult.objects.get(task_id=tid2)
+        assert tr.status == states.STARTED
+        assert date_created == tr.date_created
+        assert isinstance(tr.date_started, datetime.datetime)
+        assert tr.date_done > date_done
+
+        date_started = tr.date_started
+        date_done = tr.date_done
+
+        self.b.mark_as_done(tid2, 42)
+
+        tr = TaskResult.objects.get(task_id=tid2)
+        assert tr.status == states.SUCCESS
+        assert tr.date_created == date_created
+        assert tr.date_started == date_started
+        assert tr.date_done > date_done
+
     def xxx_backend(self):
         tid = uuid()
 
@@ -754,7 +789,7 @@ class test_DatabaseBackend:
         request.argsrepr = "argsrepr"
         request.kwargsrepr = "kwargsrepr"
         request.hostname = "celery@ip-0-0-0-0"
-        request.properties = {"periodic_task_name": "my_periodic_task"}
+        request.periodic_task_name = "my_periodic_task"
         request.ignore_result = False
         result = {"foo": "baz"}
 
@@ -804,7 +839,7 @@ class test_DatabaseBackend:
         request.argsrepr = "argsrepr"
         request.kwargsrepr = "kwargsrepr"
         request.hostname = "celery@ip-0-0-0-0"
-        request.properties = {"periodic_task_name": "my_periodic_task"}
+        request.periodic_task_name = "my_periodic_task"
         request.ignore_result = False
         request.chord.id = cid
         result = {"foo": "baz"}
@@ -850,7 +885,7 @@ class test_DatabaseBackend:
         request.argsrepr = "argsrepr"
         request.kwargsrepr = "kwargsrepr"
         request.hostname = "celery@ip-0-0-0-0"
-        request.properties = {"periodic_task_name": "my_periodic_task"}
+        request.periodic_task_name = "my_periodic_task"
         request.chord.id = cid
         result = {"foo": "baz"}
 
@@ -919,3 +954,95 @@ class test_DatabaseBackend:
         tr = TaskResult.objects.get(task_id=tid2)
         assert tr.task_args is None
         assert tr.task_kwargs is None
+
+    def test_custom_state(self):
+        tid = uuid()
+
+        assert self.b.get_status(tid) == states.PENDING
+
+        self.b.store_result(tid, state="Progress", result={"progress": 10})
+        assert self.b.get_status(tid) == "Progress"
+        assert self.b.get_result(tid) == {"progress": 10}
+
+        self.b.mark_as_done(tid, 42)
+        assert self.b.get_status(tid) == states.SUCCESS
+        assert self.b.get_result(tid) == 42
+
+
+class DjangoCeleryResultRouter:
+    route_app_labels = {"django_celery_results"}
+
+    def db_for_read(self, model, **hints):
+        """Route read access to the read-only database"""
+        if model._meta.app_label in self.route_app_labels:
+            return "read-only"
+        return None
+
+    def db_for_write(self, model, **hints):
+        """Route write access to the default database"""
+        if model._meta.app_label in self.route_app_labels:
+            return "default"
+        return None
+
+
+class ChordPartReturnTestCase(TransactionTestCase):
+    databases = {"default", "read-only"}
+
+    def setUp(self):
+        super().setUp()
+        self.app.conf.result_serializer = 'json'
+        self.app.conf.result_backend = (
+            'django_celery_results.backends:DatabaseBackend')
+        self.app.conf.result_extended = True
+        self.b = DatabaseBackend(app=self.app)
+
+    def test_on_chord_part_return_multiple_databases(self):
+        """
+        Test if the ChordCounter is properly decremented and the callback is
+        triggered after all chord parts have returned with multiple databases
+        """
+        with self.settings(DATABASE_ROUTERS=[DjangoCeleryResultRouter()]):
+            gid = uuid()
+            tid1 = uuid()
+            tid2 = uuid()
+            subtasks = [AsyncResult(tid1), AsyncResult(tid2)]
+            group = GroupResult(id=gid, results=subtasks)
+
+            assert ChordCounter.objects.count() == 0
+            assert ChordCounter.objects.using("read-only").count() == 0
+            assert ChordCounter.objects.using("default").count() == 0
+
+            self.b.apply_chord(group, self.add.s())
+
+            # Check if the ChordCounter was created in the correct database
+            assert ChordCounter.objects.count() == 1
+            assert ChordCounter.objects.using("read-only").count() == 1
+            assert ChordCounter.objects.using("default").count() == 1
+
+            chord_counter = ChordCounter.objects.get(group_id=gid)
+            assert chord_counter.count == 2
+
+            request = mock.MagicMock()
+            request.id = subtasks[0].id
+            request.group = gid
+            request.task = "my_task"
+            request.args = ["a", 1, "password"]
+            request.kwargs = {"c": 3, "d": "e", "password": "password"}
+            request.argsrepr = "argsrepr"
+            request.kwargsrepr = "kwargsrepr"
+            request.hostname = "celery@ip-0-0-0-0"
+            request.periodic_task_name = "my_periodic_task"
+            request.ignore_result = False
+            result = {"foo": "baz"}
+
+            self.b.mark_as_done(tid1, result, request=request)
+
+            chord_counter.refresh_from_db()
+            assert chord_counter.count == 1
+
+            self.b.mark_as_done(tid2, result, request=request)
+
+            with pytest.raises(ChordCounter.DoesNotExist):
+                ChordCounter.objects.get(group_id=gid)
+
+            request.chord.delay.assert_called_once()
